@@ -1,4 +1,3 @@
-
 #include <freerdp/gdi/gdi.h>
 
 #include <freerdp/gdi/dc.h>
@@ -17,8 +16,7 @@
 #include "helpers.h"
 
 /* LineTo() Test Data */
-static const BYTE line_to_case_1[256] =
-{
+static const BYTE line_to_case_1[256] = {
 	"\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -37,8 +35,7 @@ static const BYTE line_to_case_1[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_case_2[256] =
-{
+static const BYTE line_to_case_2[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -57,8 +54,7 @@ static const BYTE line_to_case_2[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00"
 };
 
-static const BYTE line_to_case_3[256] =
-{
+static const BYTE line_to_case_3[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00\xFF\xFF"
@@ -77,8 +73,7 @@ static const BYTE line_to_case_3[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_case_4[256] =
-{
+static const BYTE line_to_case_4[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00\xFF\xFF"
@@ -97,8 +92,7 @@ static const BYTE line_to_case_4[256] =
 	"\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_case_5[256] =
-{
+static const BYTE line_to_case_5[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -117,8 +111,7 @@ static const BYTE line_to_case_5[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_case_6[256] =
-{
+static const BYTE line_to_case_6[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -137,8 +130,7 @@ static const BYTE line_to_case_6[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_case_7[256] =
-{
+static const BYTE line_to_case_7[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -157,8 +149,7 @@ static const BYTE line_to_case_7[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_case_8[256] =
-{
+static const BYTE line_to_case_8[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -177,8 +168,7 @@ static const BYTE line_to_case_8[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_case_9[256] =
-{
+static const BYTE line_to_case_9[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -197,8 +187,7 @@ static const BYTE line_to_case_9[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_case_10[256] =
-{
+static const BYTE line_to_case_10[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -217,8 +206,7 @@ static const BYTE line_to_case_10[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_case_11[256] =
-{
+static const BYTE line_to_case_11[256] = {
 	"\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -237,23 +225,12 @@ static const BYTE line_to_case_11[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00"
 };
 
-static const BYTE* line_to_case[] =
-{
-	line_to_case_1,
-	line_to_case_2,
-	line_to_case_3,
-	line_to_case_4,
-	line_to_case_5,
-	line_to_case_6,
-	line_to_case_7,
-	line_to_case_8,
-	line_to_case_9,
-	line_to_case_10,
-	line_to_case_11
-};
+static const BYTE* line_to_case[] = { line_to_case_1,  line_to_case_2, line_to_case_3,
+	                                  line_to_case_4,  line_to_case_5, line_to_case_6,
+	                                  line_to_case_7,  line_to_case_8, line_to_case_9,
+	                                  line_to_case_10, line_to_case_11 };
 
-static const BYTE line_to_R2_BLACK[256] =
-{
+static const BYTE line_to_R2_BLACK[256] = {
 	"\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -272,8 +249,7 @@ static const BYTE line_to_R2_BLACK[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00"
 };
 
-static const BYTE line_to_R2_NOTMERGEPEN[256] =
-{
+static const BYTE line_to_R2_NOTMERGEPEN[256] = {
 	"\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -292,8 +268,7 @@ static const BYTE line_to_R2_NOTMERGEPEN[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00"
 };
 
-static const BYTE line_to_R2_MASKNOTPEN[256] =
-{
+static const BYTE line_to_R2_MASKNOTPEN[256] = {
 	"\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -312,8 +287,7 @@ static const BYTE line_to_R2_MASKNOTPEN[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00"
 };
 
-static const BYTE line_to_R2_NOTCOPYPEN[256] =
-{
+static const BYTE line_to_R2_NOTCOPYPEN[256] = {
 	"\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -332,8 +306,7 @@ static const BYTE line_to_R2_NOTCOPYPEN[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00"
 };
 
-static const BYTE line_to_R2_MASKPENNOT[256] =
-{
+static const BYTE line_to_R2_MASKPENNOT[256] = {
 	"\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -352,8 +325,7 @@ static const BYTE line_to_R2_MASKPENNOT[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00"
 };
 
-static const BYTE line_to_R2_NOT[256] =
-{
+static const BYTE line_to_R2_NOT[256] = {
 	"\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -372,8 +344,7 @@ static const BYTE line_to_R2_NOT[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00"
 };
 
-static const BYTE line_to_R2_XORPEN[256] =
-{
+static const BYTE line_to_R2_XORPEN[256] = {
 	"\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -392,8 +363,7 @@ static const BYTE line_to_R2_XORPEN[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00"
 };
 
-static const BYTE line_to_R2_NOTMASKPEN[256] =
-{
+static const BYTE line_to_R2_NOTMASKPEN[256] = {
 	"\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -412,8 +382,7 @@ static const BYTE line_to_R2_NOTMASKPEN[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00"
 };
 
-static const BYTE line_to_R2_MASKPEN[256] =
-{
+static const BYTE line_to_R2_MASKPEN[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -432,8 +401,7 @@ static const BYTE line_to_R2_MASKPEN[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_R2_NOTXORPEN[256] =
-{
+static const BYTE line_to_R2_NOTXORPEN[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -452,8 +420,7 @@ static const BYTE line_to_R2_NOTXORPEN[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_R2_NOP[256] =
-{
+static const BYTE line_to_R2_NOP[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -472,8 +439,7 @@ static const BYTE line_to_R2_NOP[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_R2_MERGENOTPEN[256] =
-{
+static const BYTE line_to_R2_MERGENOTPEN[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -492,8 +458,7 @@ static const BYTE line_to_R2_MERGENOTPEN[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_R2_COPYPEN[256] =
-{
+static const BYTE line_to_R2_COPYPEN[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -512,8 +477,7 @@ static const BYTE line_to_R2_COPYPEN[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_R2_MERGEPENNOT[256] =
-{
+static const BYTE line_to_R2_MERGEPENNOT[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -532,8 +496,7 @@ static const BYTE line_to_R2_MERGEPENNOT[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_R2_MERGEPEN[256] =
-{
+static const BYTE line_to_R2_MERGEPEN[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -552,8 +515,7 @@ static const BYTE line_to_R2_MERGEPEN[256] =
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 };
 
-static const BYTE line_to_R2_WHITE[256] =
-{
+static const BYTE line_to_R2_WHITE[256] = {
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
 	"\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF"
@@ -580,9 +542,9 @@ struct ropMap
 	const BYTE* src;
 };
 
-static BOOL test_line(HGDI_DC hdc, const gdiPalette* hPalette, UINT32 mX,
-                      UINT32 mY, UINT32 lX, UINT32 lY, HGDI_BITMAP hBmp,
-                      HGDI_BITMAP hOrgBmp, UINT32 cX, UINT32 cY, UINT32 cW, UINT32 cH)
+static BOOL test_line(HGDI_DC hdc, const gdiPalette* hPalette, UINT32 mX, UINT32 mY, UINT32 lX,
+                      UINT32 lY, HGDI_BITMAP hBmp, HGDI_BITMAP hOrgBmp, UINT32 cX, UINT32 cY,
+                      UINT32 cW, UINT32 cH)
 {
 	if (!gdi_BitBlt(hdc, 0, 0, 16, 16, hdc, 0, 0, GDI_WHITENESS, hPalette))
 		return FALSE;
@@ -602,63 +564,49 @@ static BOOL test_line(HGDI_DC hdc, const gdiPalette* hPalette, UINT32 mX,
 int TestGdiLine(int argc, char* argv[])
 {
 	int rc = -1;
-	UINT32 x, i;
-	gdiPalette g;
-	const UINT32 RawFormat = PIXEL_FORMAT_RGB8;
-	const UINT32 colorFormats[] =
-	{
-		PIXEL_FORMAT_RGB15,
-		PIXEL_FORMAT_ARGB15,
-		PIXEL_FORMAT_RGB16,
-		PIXEL_FORMAT_RGB24,
-		PIXEL_FORMAT_ARGB32,
-		PIXEL_FORMAT_XRGB32,
-		PIXEL_FORMAT_RGBA32,
-		PIXEL_FORMAT_RGBX32,
-		PIXEL_FORMAT_BGR15,
-		PIXEL_FORMAT_ABGR15,
-		PIXEL_FORMAT_BGR16,
-		PIXEL_FORMAT_BGR24,
-		PIXEL_FORMAT_ABGR32,
-		PIXEL_FORMAT_XBGR32,
-		PIXEL_FORMAT_BGRA32,
-		PIXEL_FORMAT_BGRX32
-	};
-	const UINT32 number_formats = sizeof(colorFormats) / sizeof(colorFormats[0]);
 
-	for (i = 0; i < number_formats; i++)
+	const UINT32 RawFormat = PIXEL_FORMAT_RGB8;
+	const UINT32 colorFormats[] = { PIXEL_FORMAT_RGB15,  PIXEL_FORMAT_ARGB15, PIXEL_FORMAT_RGB16,
+		                            PIXEL_FORMAT_RGB24,  PIXEL_FORMAT_ARGB32, PIXEL_FORMAT_XRGB32,
+		                            PIXEL_FORMAT_RGBA32, PIXEL_FORMAT_RGBX32, PIXEL_FORMAT_BGR15,
+		                            PIXEL_FORMAT_ABGR15, PIXEL_FORMAT_BGR16,  PIXEL_FORMAT_BGR24,
+		                            PIXEL_FORMAT_ABGR32, PIXEL_FORMAT_XBGR32, PIXEL_FORMAT_BGRA32,
+		                            PIXEL_FORMAT_BGRX32 };
+	const size_t number_formats = sizeof(colorFormats) / sizeof(colorFormats[0]);
+	WINPR_UNUSED(argc);
+	WINPR_UNUSED(argv);
+
+	for (size_t ifmt = 0; ifmt < number_formats; ifmt++)
 	{
+		gdiPalette g = { 0 };
 		HGDI_DC hdc = NULL;
 		HGDI_PEN pen = NULL;
 		HGDI_BITMAP hBmp = NULL;
-		struct ropMap rop_map[] =
-		{
-			{GDI_R2_BLACK, NULL, line_to_R2_BLACK},
-			{GDI_R2_NOTMERGEPEN, NULL, line_to_R2_NOTMERGEPEN},
-			{GDI_R2_MASKNOTPEN, NULL, line_to_R2_MASKNOTPEN},
-			{GDI_R2_NOTCOPYPEN, NULL, line_to_R2_NOTCOPYPEN},
-			{GDI_R2_MASKPENNOT, NULL, line_to_R2_MASKPENNOT},
-			{GDI_R2_NOT, NULL, line_to_R2_NOT},
-			{GDI_R2_XORPEN, NULL, line_to_R2_XORPEN},
-			{GDI_R2_NOTMASKPEN, NULL, line_to_R2_NOTMASKPEN},
-			{GDI_R2_MASKPEN, NULL, line_to_R2_MASKPEN},
-			{GDI_R2_NOTXORPEN, NULL, line_to_R2_NOTXORPEN},
-			{GDI_R2_NOP, NULL, line_to_R2_NOP},
-			{GDI_R2_MERGENOTPEN, NULL, line_to_R2_MERGENOTPEN},
-			{GDI_R2_COPYPEN, NULL, line_to_R2_COPYPEN},
-			{GDI_R2_MERGEPENNOT, NULL, line_to_R2_MERGEPENNOT},
-			{GDI_R2_MERGEPEN, NULL, line_to_R2_MERGEPEN},
-			{GDI_R2_WHITE, NULL, line_to_R2_WHITE}
-		};
-		const UINT32 map_size = sizeof(rop_map) / sizeof(rop_map[0]);
-		HGDI_BITMAP hBmp_LineTo[LINTETO_NUMBER] = {NULL};
+		struct ropMap rop_map[] = { { GDI_R2_BLACK, NULL, line_to_R2_BLACK },
+			                        { GDI_R2_NOTMERGEPEN, NULL, line_to_R2_NOTMERGEPEN },
+			                        { GDI_R2_MASKNOTPEN, NULL, line_to_R2_MASKNOTPEN },
+			                        { GDI_R2_NOTCOPYPEN, NULL, line_to_R2_NOTCOPYPEN },
+			                        { GDI_R2_MASKPENNOT, NULL, line_to_R2_MASKPENNOT },
+			                        { GDI_R2_NOT, NULL, line_to_R2_NOT },
+			                        { GDI_R2_XORPEN, NULL, line_to_R2_XORPEN },
+			                        { GDI_R2_NOTMASKPEN, NULL, line_to_R2_NOTMASKPEN },
+			                        { GDI_R2_MASKPEN, NULL, line_to_R2_MASKPEN },
+			                        { GDI_R2_NOTXORPEN, NULL, line_to_R2_NOTXORPEN },
+			                        { GDI_R2_NOP, NULL, line_to_R2_NOP },
+			                        { GDI_R2_MERGENOTPEN, NULL, line_to_R2_MERGENOTPEN },
+			                        { GDI_R2_COPYPEN, NULL, line_to_R2_COPYPEN },
+			                        { GDI_R2_MERGEPENNOT, NULL, line_to_R2_MERGEPENNOT },
+			                        { GDI_R2_MERGEPEN, NULL, line_to_R2_MERGEPEN },
+			                        { GDI_R2_WHITE, NULL, line_to_R2_WHITE } };
+		const size_t map_size = sizeof(rop_map) / sizeof(rop_map[0]);
+		HGDI_BITMAP hBmp_LineTo[LINTETO_NUMBER] = { NULL };
 		gdiPalette* hPalette = &g;
-		UINT32 penColor;
-		const UINT32 format = colorFormats[i];
+		UINT32 penColor = 0;
+		const UINT32 format = colorFormats[ifmt];
 		g.format = format;
 
-		for (i = 0; i < 256; i++)
-			g.palette[i] = FreeRDPGetColor(format, i, i, i, 0xFF);
+		for (unsigned x = 0; x < 256; x++)
+			g.palette[x] = FreeRDPGetColor(format, x, x, x, 0xFF);
 
 		rc = -1;
 
@@ -678,23 +626,23 @@ int TestGdiLine(int argc, char* argv[])
 			goto fail;
 		}
 
-		gdi_SelectObject(hdc, (HGDIOBJECT) pen);
+		gdi_SelectObject(hdc, (HGDIOBJECT)pen);
 		hBmp = gdi_CreateCompatibleBitmap(hdc, 16, 16);
-		gdi_SelectObject(hdc, (HGDIOBJECT) hBmp);
+		gdi_SelectObject(hdc, (HGDIOBJECT)hBmp);
 
-		for (x = 0; x < LINTETO_NUMBER; x++)
+		for (UINT32 x = 0; x < LINTETO_NUMBER; x++)
 		{
-			hBmp_LineTo[x] = test_convert_to_bitmap(line_to_case[x], RawFormat, 0, 0, 0,
-			                                        format, 0, 0, 0, 16, 16, hPalette);
+			hBmp_LineTo[x] = test_convert_to_bitmap(line_to_case[x], RawFormat, 0, 0, 0, format, 0,
+			                                        0, 0, 16, 16, hPalette);
 
 			if (!hBmp_LineTo[x])
 				goto fail;
 		}
 
-		for (x = 0; x < map_size; x++)
+		for (UINT32 x = 0; x < map_size; x++)
 		{
-			rop_map[x].bmp = test_convert_to_bitmap(rop_map[x].src, RawFormat, 0, 0, 0,
-			                                        format, 0, 0, 0, 16, 16, hPalette);
+			rop_map[x].bmp = test_convert_to_bitmap(rop_map[x].src, RawFormat, 0, 0, 0, format, 0,
+			                                        0, 0, 16, 16, hPalette);
 
 			if (!rop_map[x].bmp)
 				goto fail;
@@ -730,13 +678,12 @@ int TestGdiLine(int argc, char* argv[])
 		if (!test_line(hdc, hPalette, 0, 0, 16, 16, hBmp, hBmp_LineTo[9], 5, 5, 8, 8))
 			goto fail;
 
-		if (!test_line(hdc, hPalette, 0, 0, 26, 26, hBmp, hBmp_LineTo[10], 0, 0, 16,
-		               16))
+		if (!test_line(hdc, hPalette, 0, 0, 26, 26, hBmp, hBmp_LineTo[10], 0, 0, 16, 16))
 			goto fail;
 
-		for (x = 0; x < map_size; x++)
+		for (UINT32 x = 0; x < map_size; x++)
 		{
-			char name[1024];
+			char name[1024] = { 0 };
 			_snprintf(name, sizeof(name), "%s [%s]", gdi_rop_to_string(rop_map[x].rop),
 			          FreeRDPGetColorFormatName(hdc->format));
 
@@ -752,23 +699,21 @@ int TestGdiLine(int argc, char* argv[])
 			gdi_SetROP2(hdc, rop_map[x].rop);
 			gdi_LineTo(hdc, 16, 16);
 
-			if (!test_assert_bitmaps_equal(hBmp, rop_map[x].bmp,
-			                               name,
-			                               hPalette))
+			if (!test_assert_bitmaps_equal(hBmp, rop_map[x].bmp, name, hPalette))
 				goto fail;
 		}
 
 		rc = 0;
 	fail:
 
-		for (x = 0; x < LINTETO_NUMBER; x++)
-			gdi_DeleteObject((HGDIOBJECT) hBmp_LineTo[x]);
+		for (UINT32 x = 0; x < LINTETO_NUMBER; x++)
+			gdi_DeleteObject((HGDIOBJECT)hBmp_LineTo[x]);
 
-		for (x = 0; x < map_size; x++)
-			gdi_DeleteObject((HGDIOBJECT) rop_map[x].bmp);
+		for (UINT32 x = 0; x < map_size; x++)
+			gdi_DeleteObject((HGDIOBJECT)rop_map[x].bmp);
 
 		gdi_DeleteObject((HGDIOBJECT)hBmp);
-		gdi_DeleteObject((HGDIOBJECT) pen);
+		gdi_DeleteObject((HGDIOBJECT)pen);
 		gdi_DeleteDC(hdc);
 
 		if (rc != 0)
