@@ -36,8 +36,8 @@ extern "C"
 	rdpShadowSurface* shadow_surface_new(rdpShadowServer* server, UINT16 x, UINT16 y, UINT32 width,
 	                                     UINT32 height);
 
-	WINPR_ATTR_NODISCARD BOOL shadow_surface_resize(rdpShadowSurface* surface, UINT16 x, UINT16 y,
-	                                                UINT32 width, UINT32 height);
+	BOOL shadow_surface_resize(rdpShadowSurface* surface, UINT16 x, UINT16 y, UINT32 width,
+	                           UINT32 height);
 
 #ifdef __cplusplus
 }
